@@ -2,6 +2,7 @@ use {
     crate::*,
     anyhow::*,
     lazy_regex::regex_is_match,
+    schemars::JsonSchema,
     serde::Deserialize,
     std::{
         collections::HashMap,
@@ -15,43 +16,54 @@ use {
 ///
 /// Leaf values are options (and not Default) so that they don't
 /// override previously set values when applied to settings.
-#[derive(Debug, Clone, Deserialize)]
+#[derive(Debug, Clone, Deserialize, JsonSchema)]
 pub struct Config {
+    /// Extra arguments appended when a job runs a cargo alias.
     pub additional_alias_args: Option<Vec<String>>,
 
+    /// Name of the job to run when no job was requested explicitly.
     pub default_job: Option<ConcreteJobRef>,
 
     /// Default config for a job
     #[serde(flatten)]
     pub all_jobs: Job,
 
-    /// locations export
+    /// Deprecated single export configuration; use `exports.locations` instead.
     #[deprecated(since = "2.22.0", note = "use exports.locations")]
     pub export: Option<ExportConfig>,
 
+    /// Deprecated toggle for the legacy locations export; use `exports.locations.auto`
     #[deprecated(since = "2.9.0", note = "use exports.locations.auto")]
     pub export_locations: Option<bool>,
 
+    /// Export configurations keyed by their name.
     #[serde(default)]
     pub exports: HashMap<String, ExportConfig>,
 
+    /// Whether to display the contextual help line
     pub help_line: Option<bool>,
 
+    /// Job definitions keyed by their identifier
     #[serde(default)]
     pub jobs: HashMap<String, Job>,
 
+    /// Custom keybindings layered on top of the defaults
     pub keybindings: Option<KeyBindings>,
 
+    /// Whether to display the mission output in reverse order.
     pub reverse: Option<bool>,
 
+    /// Whether to show diagnostics summarized instead of full
     pub summary: Option<bool>,
 
+    /// Deprecated toggle that enables a built-in set of Vim-style keybindings. Use `keybindings` instead
     #[deprecated(since = "2.0.0", note = "use keybindings")]
     pub vim_keys: Option<bool>,
 
     /// Whether to listen for actions on a unix socket (if on unix)
     pub listen: Option<bool>,
 
+    /// Whether to wrap long lines
     pub wrap: Option<bool>,
 }
 
@@ -75,13 +87,13 @@ impl Config {
     /// Load a configuration item filling the provided path in TOML
     pub fn from_path(path: &Path) -> Result<Self> {
         let conf = toml::from_str::<Self>(&fs::read_to_string(path)?)
-            .with_context(|| format!("Failed to parse configuration file at {:?}", path))?;
+            .with_context(|| format!("Failed to parse configuration file at {path:?}"))?;
         for (name, job) in &conf.jobs {
             if !regex_is_match!(r#"^[\w-]+$"#, name) {
-                bail!("Invalid configuration : Illegal job name : {:?}", name);
+                bail!("Invalid configuration : Illegal job name : {name:?}");
             }
             if job.command.is_empty() {
-                bail!("Invalid configuration : empty command for job {:?}", name);
+                bail!("Invalid configuration : empty command for job {name:?}");
             }
         }
         Ok(conf)
