@@ -41,7 +41,7 @@ pub struct TaskExecutor {
     grace_period: Period,
 }
 
-/// A message sent to the child_thread on end
+/// A message sent to the `child_thread` on end
 #[derive(Clone, Copy)]
 enum StopMessage {
     SendStatus, // process already finished, just get status
@@ -241,7 +241,7 @@ fn kill(
         };
         warn!("specific kill command failed: {e}");
     }
-    child.kill().expect("command couldn't be killed")
+    child.kill().expect("command couldn't be killed");
 }
 
 fn run_kill_command(
