@@ -1,5 +1,6 @@
 use {
     crate::*,
+    schemars::JsonSchema,
     serde::Deserialize,
     std::{
         collections::HashMap,
@@ -8,7 +9,7 @@ use {
 };
 
 /// One of the possible jobs that bacon can run
-#[derive(Debug, Default, Clone, Deserialize, PartialEq)]
+#[derive(Debug, Default, Clone, Deserialize, PartialEq, JsonSchema)]
 pub struct Job {
     /// Whether to consider that we can have a success
     /// when we have test failures
@@ -59,6 +60,12 @@ pub struct Job {
     /// Eg: --all-features or anything after -- in bacon incantation
     pub extraneous_args: Option<bool>,
 
+    /// Minimum delay to wait before restarting the job after a change is detected.
+    pub grace_period: Option<Period>,
+
+    /// Whether to hide the scrollbar
+    pub hide_scrollbar: Option<bool>,
+
     /// A list of glob patterns to ignore
     #[serde(default)]
     pub ignore: Vec<String>,
@@ -79,9 +86,13 @@ pub struct Job {
     /// restarting it.
     pub on_change_strategy: Option<OnChangeStrategy>,
 
+    /// The optional action to run when it's not a success
+    #[serde(default)]
+    pub on_failure: Option<Action>,
+
     /// The optional action to run when there's no
     /// error, warning or test failures
-    /// (depending on whether allow_warnings is true or false)
+    /// (depending on whether `allow_warnings` is `true` or `false`)
     ///
     /// Could be made a vec in the future but that would involve
     /// explaining subtleties like the fact that those actions stop
@@ -89,11 +100,16 @@ pub struct Job {
     #[serde(default)]
     pub on_success: Option<Action>,
 
-    pub grace_period: Option<Period>,
+    /// Whether to display how many files triggered the current run.
+    pub show_changes_count: Option<bool>,
 
-    /// The optional action to run when it's not a success
+    /// Color overrides applied to the UI while the job runs.
     #[serde(default)]
-    pub on_failure: Option<Action>,
+    pub skin: BaconSkin,
+
+    /// Notification sounds
+    #[serde(default)]
+    pub sound: SoundConfig,
 
     /// A list of directories that will be watched if the job
     /// is run on a package.
@@ -101,17 +117,9 @@ pub struct Job {
     /// unless you `set default_watch` to false.
     pub watch: Option<Vec<String>>,
 
-    pub show_changes_count: Option<bool>,
-
-    #[serde(default)]
-    pub sound: SoundConfig,
-
     /// An optional working directory for the job command, which
     /// would override the package directory.
     pub workdir: Option<PathBuf>,
-
-    #[serde(default)]
-    pub skin: BaconSkin,
 }
 
 static DEFAULT_ARGS: &[&str] = &["--color", "always"];
@@ -125,11 +133,11 @@ impl Job {
         let mut command = vec!["cargo".to_string(), alias_name.to_string()];
         if let Some(additional_args) = settings.additional_alias_args.as_ref() {
             for arg in additional_args {
-                command.push(arg.to_string())
+                command.push(arg.to_string());
             }
         } else {
             for arg in DEFAULT_ARGS {
-                command.push(arg.to_string())
+                command.push(arg.to_string());
             }
         }
         Self {
@@ -152,6 +160,9 @@ impl Job {
     pub fn expand_env_vars(&self) -> bool {
         self.expand_env_vars.unwrap_or(true)
     }
+    pub fn hide_scrollbar(&self) -> bool {
+        self.hide_scrollbar.unwrap_or(false)
+    }
     pub fn need_stdout(&self) -> bool {
         self.need_stdout.unwrap_or(false)
     }
@@ -203,6 +214,9 @@ impl Job {
         if let Some(b) = job.extraneous_args {
             self.extraneous_args = Some(b);
         }
+        if let Some(b) = job.hide_scrollbar {
+            self.hide_scrollbar = Some(b);
+        }
         for v in &job.ignore {
             if !self.ignore.contains(v) {
                 self.ignore.push(v.clone());
@@ -260,6 +274,7 @@ fn test_job_apply() {
             .collect(),
         expand_env_vars: Some(false),
         extraneous_args: Some(false),
+        hide_scrollbar: Some(true),
         ignore: vec!["special-target".to_string(), "generated".to_string()],
         ignored_lines: Some(vec![LinePattern::from_str("half-error.*").unwrap()]),
         kill: Some(vec!["die".to_string()]),
