@@ -13,6 +13,13 @@ pub enum CommandStream {
     StdErr,
 }
 
+/// a line coming either from stdout or from stderr, before TTY parsing
+#[derive(Debug, Clone, Serialize, Deserialize, PartialEq, Eq)]
+pub struct RawCommandOutputLine {
+    pub content: String,
+    pub origin: CommandStream,
+}
+
 /// a line coming either from stdout or from stderr
 #[derive(Debug, Clone, Serialize, Deserialize, PartialEq, Eq)]
 pub struct CommandOutputLine {
@@ -23,7 +30,7 @@ pub struct CommandOutputLine {
 /// some output lines
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct CommandOutput {
-    pub lines: Vec<CommandOutputLine>,
+    pub lines: Vec<Line>,
 }
 
 /// a piece of information about the execution of a command
@@ -36,32 +43,32 @@ pub enum CommandExecInfo {
     Interruption,
 
     /// Execution failed
-    Error(String),
+    Error(anyhow::Error),
 
     /// Here's a line of output (coming from stderr or stdout)
-    Line(CommandOutputLine),
-}
-
-impl WrappableLine for CommandOutputLine {
-    fn content(&self) -> &TLine {
-        &self.content
-    }
-    fn prefix_cols(&self) -> usize {
-        0
-    }
+    Line(RawCommandOutputLine),
 }
 
 impl CommandOutput {
     pub fn reverse(&mut self) {
-        self.lines.reverse()
+        self.lines.reverse();
     }
-    pub fn push(
+    pub fn push<L: Into<Line>>(
         &mut self,
-        line: CommandOutputLine,
+        line: L,
     ) {
-        self.lines.push(line);
+        self.lines.push(line.into());
     }
     pub fn len(&self) -> usize {
         self.lines.len()
     }
 }
+
+impl From<RawCommandOutputLine> for CommandOutputLine {
+    fn from(raw: RawCommandOutputLine) -> Self {
+        CommandOutputLine {
+            content: TLine::from_tty(&raw.content),
+            origin: raw.origin,
+        }
+    }
+}
