@@ -18,22 +18,47 @@ use {
 /// lightly analyzed
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct Report {
+    pub output: CommandOutput,
     pub lines: Vec<Line>,
     pub stats: Stats,
     pub suggest_backtrace: bool,
-    pub output: CommandOutput,
     pub failure_keys: Vec<String>,
     /// the exports that the analyzers have done, by name
     pub analyzer_exports: HashMap<String, String>,
+
+    pub has_passed_tests: bool,
+
+    pub dismissed_items: usize,
+    pub dismissed_lines: Vec<Line>,
 }
 
 impl Report {
+    pub fn new(lines: Vec<Line>) -> Self {
+        let stats = Stats::from(&lines);
+        Self {
+            output: Default::default(),
+            lines,
+            suggest_backtrace: false,
+            failure_keys: Vec::new(),
+            analyzer_exports: Default::default(),
+            has_passed_tests: false,
+            stats,
+            dismissed_items: 0,
+            dismissed_lines: Vec::new(),
+        }
+    }
+
+    pub fn lines_changed(&mut self) {
+        self.stats = Stats::from(&self.lines);
+    }
+
     /// change the order of the lines so that items are in reverse order
     /// (but keep the order of lines of a given item)
     pub fn reverse(&mut self) {
         self.lines
             .sort_by_key(|line| std::cmp::Reverse(line.item_idx));
     }
+
     /// A successful report is one with nothing to tell: no warning,
     /// no error, no test failure
     pub fn is_success(
@@ -46,6 +71,17 @@ impl Report {
             || (!allow_warnings && self.stats.warnings != 0))
     }
 
+    pub fn remove_item(
+        &mut self,
+        item_idx: usize,
+    ) {
+        self.lines.retain(|line| line.item_idx != item_idx);
+    }
+
+    pub fn has_dismissed_items(&self) -> bool {
+        self.dismissed_items > 0
+    }
+
     pub fn focus_file(
         &mut self,
         ffc: &FocusFileCommand,
@@ -76,6 +112,39 @@ impl Report {
         }
     }
 
+    pub fn top_item_idx(&self) -> Option<usize> {
+        self.lines.first().map(|line| line.item_idx)
+    }
+
+    pub fn item_location(
+        &self,
+        item_idx: usize,
+    ) -> Option<&str> {
+        info!("looking for location of item {item_idx}");
+        self.lines
+            .iter()
+            .find(|line| line.item_idx == item_idx && line.location().is_some())
+            .and_then(|line| line.location())
+        //.and_then(|loc| loc.parse().ok())
+    }
+
+    pub fn item_diag_type(
+        &self,
+        item_idx: usize,
+    ) -> Option<&str> {
+        info!("looking for diag_type of item {item_idx}");
+        for line in &self.lines {
+            if line.item_idx != item_idx {
+                continue;
+            }
+            let diag_type = line.diag_type();
+            if diag_type.is_some() {
+                return diag_type;
+            }
+        }
+        None
+    }
+
     /// Extract all the diagnostic context, that is all the normal lines
     /// which have the same item index as the given line.
     /// Those lines are taken without style and joined with an escaped newline.
@@ -156,4 +225,7 @@ impl Report {
         debug!("exported locations");
         Ok(())
     }
+    pub fn can_scope_tests(&self) -> bool {
+        self.has_passed_tests && self.stats.test_fails > 0
+    }
 }
